YAML Builder
============

.. image:: https://travis-ci.org/spockNinja/py-yaml-builder.svg?branch=master
    :target: https://travis-ci.org/spockNinja/py-yaml-builder

A simple wrapper around `PyYAML <https://https://github.com/yaml/pyyaml>`_
for building complex YAML files.

The need for this utility arose when crafting large YAML files
for AWS CloudFormation. Just like code, it is cleaner and easier to reason
about a large YAML file if it is broken up into several smaller pieces.

`The source for this project is available here
<https://github.com/spockNinja/py-yaml-builder>`_.

----

TODO

Add some quick usage examples
Add some contributing guidelines
